@@ -1,5 +1,6 @@
 import functools
 import logging
+from enum import Enum
 from typing import Dict, Optional
 
 import esptool
@@ -7,6 +8,11 @@ from pytest_embedded.log import DuplicateStdout, PexpectProcess
 from pytest_embedded_serial.dut import Serial
 
 
+class EsptoolVersion(Enum):
+    V3 = 3
+    V4 = 4
+
+
 class EspSerial(Serial):
     """
     Serial class for ports connected to espressif products
@@ -18,6 +24,17 @@ class EspSerial(Serial):
 
     DEFAULT_BAUDRATE = 115200
 
+    try:
+        # esptool>=4.0
+        from esptool.loader import ESPLoader
+
+        ESPTOOL_VERSION = EsptoolVersion.V4
+    except (AttributeError, ModuleNotFoundError):
+        # esptool<4.0
+        from esptool import ESPLoader
+
+        ESPTOOL_VERSION = EsptoolVersion.V3
+
     def __init__(
         self,
         pexpect_proc: PexpectProcess,
